local DB = Aki.DB
local frame = Aki.frame

-- 事件处理统一模版
frame:SetScript('OnEvent', function(self, event, ...)
	local a = self[event]
	if a then
		a(self, ...)
	end
end)

-- 插件加载
frame:RegisterEvent('ADDON_LOADED')
function frame:ADDON_LOADED(name)
	if name ~= 'AkiTools' then return end
	self:UnregisterEvent('ADDON_LOADED')
	if not AkiDB then AkiDB = {} end
	Aki:UpdateDB(DB, AkiDB)
end

-- 玩家登出
frame:RegisterEvent('PLAYER_LOGOUT')
function frame:PLAYER_LOGOUT()
	Aki:UpdateDB(AkiDB, DB)
end

-- 打开商店
frame:RegisterEvent('MERCHANT_SHOW')
function frame:MERCHANT_SHOW( ) 
	local num = 0
	if DB.autoSell then
		for bag = 0, NUM_BAG_FRAMES do
			for slot = 1, GetContainerNumSlots(bag) do
				local itemId = GetContainerItemID(bag,slot)
				if itemId then 
					local _, _, itemRarity = GetItemInfo(itemId)
					if itemRarity == 0 then
						UseContainerItem(bag,slot)
						num = num +1
					end 
				end 
			end
		end
		if (num > 0) then
			print('Aki已为您自动售卖灰色物品['..num..']')
		end
	end
end

-- 战斗日志
frame:RegisterEvent('COMBAT_LOG_EVENT_UNFILTERED')
function frame:COMBAT_LOG_EVENT_UNFILTERED( ...) 
	local cfg = Aki:GetConfig()
	
	-- 读取事件返回值
	local timestamp, eventType, hideCaster, sourceGUID, sourceName, sourceFlags, sourceRaidFlags, destGUID, destName, destFlags, destRaidFlags = CombatLogGetCurrentEventInfo()
	local prefix, suffix = eventType:match('^(%u*)_(%S*)$')
	
	-- 战斗事件通报
	if prefix == 'SPELL' then
		local spellId, spellName, spellSchool = select(12, CombatLogGetCurrentEventInfo())
		if suffix == 'INTERRUPT' then
			local extraSpellId, extraSpellName, extraSchool = select(15, CombatLogGetCurrentEventInfo())
			if sourceName == UnitName('player')  or sourceName == UnitName('pet')then
				GetSpellLink(extraSpellId)
				Aki:Announce(cfg.ownInterrupt, '断 → '..GetSpellLink(extraSpellId), cfg.ownInterruptSound)
			elseif Aki:IsInMyGroup(sourceFlags) then
				local name = Aki:ShortName(sourceName)
				if cfg.other == 'self' and Aki:IsPlayer(sourceFlags) then
					name = Aki:ClassColor(name)
				end
				Aki:Announce(cfg.otherInterrupt, '['..name..']断 → '..GetSpellLink(extraSpellId), cfg.otherInterruptSound)
			end

		elseif suffix == 'DISPEL' then
			local extraSpellId, extraSpellName, extraSchool, auraType = select(15, CombatLogGetCurrentEventInfo())
			if sourceName == UnitName('player')  or sourceName == UnitName('pet')then
				Aki:Announce(cfg.ownDispel, '驱 → '..GetSpellLink(extraSpellId), cfg.ownDispelSound)
			elseif Aki:IsInMyGroup(sourceFlags) then
				local name = Aki:ShortName(sourceName)
				if cfg.other == 'self' and Aki:IsPlayer(sourceFlags) then
					name = Aki:ClassColor(name)
				end
				Aki:Announce(cfg.otherDispel, '['..name..']驱 → '..GetSpellLink(extraSpellId), cfg.otherDispelSound)
			end

		elseif suffix == 'STOLEN' then
			local extraSpellId, extraSpellName, extraSchool, auraType = select(15, CombatLogGetCurrentEventInfo())
			if sourceName == UnitName('player') then
				Aki:Announce(cfg.ownStolen, '偷 → '..GetSpellLink(extraSpellId), cfg.ownStolenSound)
			elseif Aki:IsInMyGroup(sourceFlags) then
				local name = Aki:ShortName(sourceName)
				if cfg.other == 'self' and Aki:IsPlayer(sourceFlags) then
					name = Aki:ClassColor(name)
				end
				Aki:Announce(cfg.otherStolen, '['..name..']偷 → '..GetSpellLink(extraSpellId), cfg.otherStolenSound)
			end

		elseif suffix == 'MISSED' then
			local missType, isOffHand, amountMissed = select(15, CombatLogGetCurrentEventInfo())
			if missType == 'REFLECT' and destName == UnitName('player') then 
				Aki:Announce(cfg.ownReflect, '反 → '..GetSpellLink(spellId), cfg.ownReflectSound)
			elseif missType == 'REFLECT' and Aki:IsInMyGroup(sourceFlags) then
				local name = Aki:ShortName(sourceName)
				if cfg.other == 'self' and Aki:IsPlayer(sourceFlags) then
					name = Aki:ClassColor(name)
				end
				Aki:Announce(cfg.otherReflect, '['..name..']反 → '..GetSpellLink(spellId), cfg.otherReflectSound)
			end
		end
	end
end